ete2.treeview.drawer._TableItem

Package ete2 :: Package treeview :: Module drawer :: Class _TableItem |
[hide private]
[frames] | no frames]

# Class _TableItem

source code

               object --+
                        |
        sip.simplewrapper --+
                            |
                  sip.wrapper --+
                                |
             PyQt4.QtCore.QObject --+
                                    |
    PyQt4.QtGui.QAbstractItemDelegate --+
                                        |
                PyQt4.QtGui.QItemDelegate --+
                                            |
                                           _TableItem

Nested Classes | [hide private]
Inherited from `PyQt4.QtGui.QAbstractItemDelegate`: `EndEditHint`

Instance Methods | [hide private]
__init__(self, parent=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
paint(self, painter, option, index) | source code
createEditor(self, parent, option, index) | source code
setEditorData(self, editor, index) | source code
displayText(self, value) | source code
commitAndCloseEditor(self) | source code
Inherited from `PyQt4.QtGui.QItemDelegate`: `childEvent`, `connectNotify`, `customEvent`, `disconnectNotify`, `drawBackground`, `drawCheck`, `drawDecoration`, `drawDisplay`, `drawFocus`, `editorEvent`, `eventFilter`, `hasClipping`, `itemEditorFactory`, `receivers`, `setClipping`, `setItemEditorFactory`, `setModelData`, `sizeHint`, `timerEvent`, `updateEditorGeometry` Inherited from `PyQt4.QtGui.QAbstractItemDelegate`: `closeEditor`, `commitData`, `elidedText`, `helpEvent`, `sizeHintChanged` Inherited from `PyQt4.QtCore.QObject`: `blockSignals`, `children`, `connect`, `deleteLater`, `destroyed`, `disconnect`, `dumpObjectInfo`, `dumpObjectTree`, `dynamicPropertyNames`, `emit`, `event`, `findChild`, `findChildren`, `inherits`, `installEventFilter`, `isWidgetType`, `killTimer`, `metaObject`, `moveToThread`, `objectName`, `parent`, `property`, `pyqtConfigure`, `removeEventFilter`, `sender`, `setObjectName`, `setParent`, `setProperty`, `signalsBlocked`, `startTimer`, `thread`, `tr`, `trUtf8` Inherited from `sip.simplewrapper`: `__delattr__`, `__getattribute__`, `__new__`, `__setattr__` Inherited from `object`: `__format__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Static Methods | [hide private]
isSupportedType(valueType) | source code

Class Variables | [hide private]
Inherited from `PyQt4.QtGui.QAbstractItemDelegate`: `EditNextItem`, `EditPreviousItem`, `NoHint`, `RevertModelCache`, `SubmitModelCache` Inherited from `PyQt4.QtCore.QObject`: `staticMetaObject`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, parent=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### paint(self, painter, option, index) | source code
Overrides: PyQt4.QtGui.QAbstractItemDelegate.paint

### createEditor(self, parent, option, index) | source code
Overrides: PyQt4.QtGui.QAbstractItemDelegate.createEditor

### setEditorData(self, editor, index) | source code
Overrides: PyQt4.QtGui.QAbstractItemDelegate.setEditorData